@@ -7,8 +7,8 @@ pub mod constraints;
 
 #[derive(Default, Clone)]
 pub struct Private<F: PrimeField> {
-	secret: F,
-	nullifier: F,
+	pub secret: F,
+	pub nullifier: F,
 }
 
 impl<F: PrimeField> Private<F> {
@@ -18,6 +18,13 @@ impl<F: PrimeField> Private<F> {
 			nullifier: F::rand(rng),
 		}
 	}
+
+	pub fn new(secret: F, nullifier: F) -> Self {
+		Self {
+			secret,
+			nullifier,
+		}
+	}
 }
 
 #[derive(Default, Clone)]
